==> hoteldruid-mod-ca_2.1.1-1.tar.gz: ca/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Insereix una reserva nova"; break;
case "Cliente titolare: cognome":  		$messaggio = "Client titular: cognoms"; break;
case "cognome":  				$messaggio = "Cognoms"; break;
case "nome":  					$messaggio = "Nom"; break;
case "Dal":  					$messaggio = "Arribada"; break;
case "dal":  					$messaggio = "arribada"; break;
case "al":  					$messaggio = "Sortida"; break;
case "Tipo di tariffa":  			$messaggio = "Tipus de tarifa"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "sconto":  				$messaggio = "descompte"; break;
case "caparra":  				$messaggio = "Arres"; break;
case "se diversa dalla normale":  		$messaggio = "si difereix de la normal"; break;
case "nº di persone":  				$messaggio = "n° de persones"; break;
case "Nº di piano":  				$messaggio = "N° de pis"; break;
case "e/o di casa":  				$messaggio = "i/o de casa"; break;
case "e/o di persone":  			$messaggio = "i/o de persones"; break;
case "costo aggiuntivo unico":  		$messaggio = "suplement puntual"; break;
case "da moltiplicare per":  			$messaggio = "a multiplicar per"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "suplement semtanal"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "suplement diari"; break;
case "nº di settimane da applicare":  		$messaggio = "nº de setmanes a aplicar"; break;
case "nº di giorni da applicare":  		$messaggio = "nº de dies a aplicar"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insereix la reserva"; break;
case "Torna al menù principale":  		$messaggio = "Torna al menú principal"; break;
case " o spezzarla":  				$messaggio = " o dividir-la"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divideix la reserva en"; break;
case "parti":  					$messaggio = "trams"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "No ha estat possible dividir la reserva a causa del número de persones"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "No és posible inserir la reserva sense"; break;
case "dividerla":  				$messaggio = "dividir-la"; break;
case "in":  					$messaggio = "en"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divideix la reserva en"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "No s'ha pogut inserir la reserva a nom de"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "porquè la base de dades ha enregistrat canvit durant el procés"; break;
case "Prenotazione":  				$messaggio = "Reserva"; break;
case "settiman":  				$messaggio = "setmana"; break;
case "giorn":  					$messaggio = "dia"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "a nom de"; break;
case "per":  					$messaggio = "per"; break;
case "persone":  				$messaggio = "persones"; break;
case "Costo unico":  				$messaggio = "Cost puntual"; break;
case "moltiplicato per":  			$messaggio = "multiplicat per"; break;
case "Costo settimanale":  			$messaggio = "Cost setmanal"; break;
case "Costo giornaliero":  			$messaggio = "Cost diari"; break;
case "settimane":  				$messaggio = "setmanes"; break;
case "giorni":  				$messaggio = "dias"; break;
case "Caparra":  				$messaggio = "Arres"; break;
case "resto da pagare":  			$messaggio = "manca per pagar"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "inserita":  				$messaggio = "inserida"; break;
case "Modifica la prenotazione":  		$messaggio = "Modifica la reserva"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Sconto":  				$messaggio = "Descompte"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "És necessari inserir el cognom del client"; break;
case "confermata":  				$messaggio = "confirmada"; break;
case "Confermata":  				$messaggio = "Confirmada"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Nº de reserves d'aquesta tipologia"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Afegeix d'altres tipologies"; break;
case "Tipologia":  				$messaggio = "Tipologia"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "No s'ha inserir cap reserva"; break;
case "Transazione scaduta":  			$messaggio = "Transacció caducada"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "No s'ha pogut inserir cap suplement a la reserva a nom de"; break;
case "Orario stimato di entrata":  		$messaggio = "Horari d'entrada orientatiu"; break;
case "giorno":  				$messaggio = "dia"; break;
case "Metodo pagamento caparra":  		$messaggio = "Mitjà de pagament de les arres"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Les reserves sol·licitades al missatge ja han estat inserides"; break;
case "Attenzione":  				$messaggio = "Atenció"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "el preu total de les reserves inserides"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "el preu total de les pagues i senyals inserides"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "difereix del que s'especifica al missatge de sol·licitud de reserva"; break;
case "Origine":  				$messaggio = "Origen"; break;
case "<b>Attenzione</b>: il prezzo totale":  	$messaggio = "<b>Atenció</b>: el preu total"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "no coincideix amb el preu remot"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modifica en bloc les reserves inserides"; break;
case "prezzo totale":  				$messaggio = "preu total"; break;
case "prezzo totale giornaliero":  		$messaggio = "preu total diari"; break;
case "prezzo totale settimanale":  		$messaggio = "preu total setmanal"; break;
case "prezzo tarffa":  				$messaggio = "preu tarifa"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "preu tarifa diari"; break;
case "prezzo tariffa settimanale":  		$messaggio = "preu tarifa setmanal"; break;
case "% del totale":  				$messaggio = "% del total"; break;
case "% della tariffa":  			$messaggio = "% de la tarifa"; break;
case "Commissioni":  				$messaggio = "Comissions"; break;
case "resto commissioni":  			$messaggio = "resta comissions"; break;
case "% del prezzo totale":  			$messaggio = "% del preu total"; break;
case "modificata":  				$messaggio = "modificada"; break;
case "costo aggiuntivo":  			$messaggio = "suplement"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Errore":  				$messaggio = "Error"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "per l'entrata":  				$messaggio = "for checkin"; break;
case "per l'uscita":  				$messaggio = "for checkout"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ca_2.1.3-1.tar.gz: ca/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Insereix una reserva nova"; break;
case "Cliente titolare: cognome":  		$messaggio = "Client titular: cognoms"; break;
case "cognome":  				$messaggio = "Cognoms"; break;
case "nome":  					$messaggio = "Nom"; break;
case "Dal":  					$messaggio = "Arribada"; break;
case "dal":  					$messaggio = "arribada"; break;
case "al":  					$messaggio = "Sortida"; break;
case "Tipo di tariffa":  			$messaggio = "Tipus de tarifa"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "sconto":  				$messaggio = "descompte"; break;
case "caparra":  				$messaggio = "Arres"; break;
case "se diversa dalla normale":  		$messaggio = "si difereix de la normal"; break;
case "nº di persone":  				$messaggio = "n° de persones"; break;
case "Nº di piano":  				$messaggio = "N° de pis"; break;
case "e/o di casa":  				$messaggio = "i/o de casa"; break;
case "e/o di persone":  			$messaggio = "i/o de persones"; break;
case "costo aggiuntivo unico":  		$messaggio = "suplement puntual"; break;
case "da moltiplicare per":  			$messaggio = "a multiplicar per"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "suplement semtanal"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "suplement diari"; break;
case "nº di settimane da applicare":  		$messaggio = "nº de setmanes a aplicar"; break;
case "nº di giorni da applicare":  		$messaggio = "nº de dies a aplicar"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insereix la reserva"; break;
case "Torna al menù principale":  		$messaggio = "Torna al menú principal"; break;
case " o spezzarla":  				$messaggio = " o dividir-la"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divideix la reserva en"; break;
case "parti":  					$messaggio = "trams"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "No ha estat possible dividir la reserva a causa del número de persones"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "No és posible inserir la reserva sense"; break;
case "dividerla":  				$messaggio = "dividir-la"; break;
case "in":  					$messaggio = "en"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divideix la reserva en"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "No s'ha pogut inserir la reserva a nom de"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "porquè la base de dades ha enregistrat canvit durant el procés"; break;
case "Prenotazione":  				$messaggio = "Reserva"; break;
case "settiman":  				$messaggio = "setmana"; break;
case "giorn":  					$messaggio = "dia"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "a nom de"; break;
case "per":  					$messaggio = "per"; break;
case "persone":  				$messaggio = "persones"; break;
case "Costo unico":  				$messaggio = "Cost puntual"; break;
case "moltiplicato per":  			$messaggio = "multiplicat per"; break;
case "Costo settimanale":  			$messaggio = "Cost setmanal"; break;
case "Costo giornaliero":  			$messaggio = "Cost diari"; break;
case "settimane":  				$messaggio = "setmanes"; break;
case "giorni":  				$messaggio = "dias"; break;
case "Caparra":  				$messaggio = "Arres"; break;
case "resto da pagare":  			$messaggio = "manca per pagar"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "inserita":  				$messaggio = "inserida"; break;
case "Modifica la prenotazione":  		$messaggio = "Modifica la reserva"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Sconto":  				$messaggio = "Descompte"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "És necessari inserir el cognom del client"; break;
case "confermata":  				$messaggio = "confirmada"; break;
case "Confermata":  				$messaggio = "Confirmada"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Nº de reserves d'aquesta tipologia"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Afegeix d'altres tipologies"; break;
case "Tipologia":  				$messaggio = "Tipologia"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "No s'ha inserir cap reserva"; break;
case "Transazione scaduta":  			$messaggio = "Transacció caducada"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "No s'ha pogut inserir cap suplement a la reserva a nom de"; break;
case "Orario stimato di entrata":  		$messaggio = "Horari d'entrada orientatiu"; break;
case "giorno":  				$messaggio = "dia"; break;
case "Metodo pagamento caparra":  		$messaggio = "Mitjà de pagament de les arres"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Les reserves sol·licitades al missatge ja han estat inserides"; break;
case "Attenzione":  				$messaggio = "Atenció"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "el preu total de les reserves inserides"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "el preu total de les pagues i senyals inserides"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "difereix del que s'especifica al missatge de sol·licitud de reserva"; break;
case "Origine":  				$messaggio = "Origen"; break;
case "<b>Attenzione</b>: il prezzo totale":  	$messaggio = "<b>Atenció</b>: el preu total"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "no coincideix amb el preu remot"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modifica en bloc les reserves inserides"; break;
case "prezzo totale":  				$messaggio = "preu total"; break;
case "prezzo totale giornaliero":  		$messaggio = "preu total diari"; break;
case "prezzo totale settimanale":  		$messaggio = "preu total setmanal"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "preu tarifa diari"; break;
case "prezzo tariffa settimanale":  		$messaggio = "preu tarifa setmanal"; break;
case "% del totale":  				$messaggio = "% del total"; break;
case "% della tariffa":  			$messaggio = "% de la tarifa"; break;
case "Commissioni":  				$messaggio = "Comissions"; break;
case "resto commissioni":  			$messaggio = "resta comissions"; break;
case "% del prezzo totale":  			$messaggio = "% del preu total"; break;
case "modificata":  				$messaggio = "modificada"; break;
case "costo aggiuntivo":  			$messaggio = "suplement"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Errore":  				$messaggio = "Error"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
